<?php
/**
 * Custom template tags for this theme
 * @package the-business-wp
 * @since 1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
 
if ( ! function_exists( 'the_business_wp_featured_areas' ) ) : 
/**
 * the-business-wp featured areas
 * @package the-business-wp
 * @since 1.0 
 */
 
function the_business_wp_featured_areas(){
$featured = array(
	    'slider'=> __('Home Slider','the-business-wp'),
		'hero'=> __('Hero','the-business-wp'),
		'service'=> __('Service','the-business-wp'),
		'woocommerce'=> __('Shop','the-business-wp'),
		'callout'=> __('Callout','the-business-wp'),
		'team'=> __('Team','the-business-wp'),
		'skills'=> __('Skills','the-business-wp'),
		'testimonial'=> __('Testimonial','the-business-wp'),
		'news'=> __('News','the-business-wp'),
		'contact'=> __('Contact','the-business-wp'),
		'none'=> __('None','the-business-wp'),
	);
		
	return 	$featured;	
}

endif;

if ( ! function_exists( 'the_business_wp_color_codes' ) ) : 
/**
 * the-business-wp color codes
 * @package the-business-wp
 * @since 1.0 
 */
 
function the_business_wp_color_codes(){
	return array('#000000','#ffffff','#ED0A70','#e7ad24','#FFD700','#81d742','#0053f9','#8224e3');
}

endif;

if ( ! function_exists( 'the_business_wp_background_style' ) ) : 
/**
 * the-business-wp color codes
 * @package the-business-wp
 * @since 1.0 
 */
 
function the_business_wp_background_style(){
	return array(
					'no-repeat'  => __('No Repeat','the-business-wp'),
					'repeat'     => __('Tile','the-business-wp'),
					'repeat-x'   => __('Tile Horizontally','the-business-wp'),
					'repeat-y'   => __('Tile Vertically','the-business-wp'),
				);
}

endif;


/**
 * @Package twentyseventeen
 * @subpackage the-business-wp
 * @since the-business-wp 1.0
 */
if ( ! function_exists( 'the_business_wp_posted_on' ) ) : 
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function the_business_wp_posted_on() {
		
		$byline = sprintf(
			// Get the author name; wrap it in a link.
			esc_html_x( 'By %s', 'post author', 'the-business-wp' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);		

		// Finally, let's write all of this to the page.
		echo '<span class="posted-on">' . the_business_wp_time_link() . '</span><span class="byline"> ' . $byline . '</span>';
	}
endif;

/**
 * @Package twentyseventeen
 * @subpackage the-business-wp
 * @since the-business-wp 1.0
 */
if ( ! function_exists( 'the_business_wp_time_link' ) ) :
	/**
	 * Gets a nicely formatted string for the published date.
	 */
	function the_business_wp_time_link() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf(
			$time_string,
			get_the_date( DATE_W3C ),
			get_the_date(),
			get_the_modified_date( DATE_W3C ),
			get_the_modified_date()
		);
		
		$args = array( 'time'=> array('class'=> array(),'datetime'=>array()));
		
		$time_string = wp_kses($time_string, $args);
		// Wrap the time string in a link, and preface it with 'Posted on'.
		return sprintf(
			/* translators: %s: post date */
			__( '<span class="screen-reader-text">Posted on</span> %s', 'the-business-wp' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' .$time_string. '</a>'
		);
	}
endif;

/**
 * @Package twentyseventeen
 * @subpackage the-business-wp
 * @since the-business-wp 1.0
 */
if ( ! function_exists( 'the_business_wp_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function the_business_wp_entry_footer() {
	
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ', ', 'the-business-wp' ) );
		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html__( ', ', 'the-business-wp' ) );
				
		// We don't want to output .entry-footer if it will be empty, so make sure its not.
		if ( ( ( the_business_wp_categorized_blog() && $categories_list ) || $tags_list ) || get_edit_post_link() ) {

			echo '<footer class="entry-footer">';

			if ( 'post' === get_post_type() ) {

				
				if ( ( $categories_list && the_business_wp_categorized_blog() ) || $tags_list ) {
					echo '<span class="cat-tags-links">';

					// Make sure there's more than one category before displaying.
					if ( $categories_list && the_business_wp_categorized_blog() ) {
						
						echo '<span class="cat-links">' . the_business_wp_get_fo( array( 'icon' => 'folder-open' ) ) . '<span class="screen-reader-text">' . esc_html__( 'Categories', 'the-business-wp' ) . '</span>' .$categories_list. '</span>';
					}
					
					if ( $tags_list && ! is_wp_error( $tags_list ) ) {
					
						echo '<span class="tags-links">' . the_business_wp_get_fo( array( 'icon' => 'hashtag' ) ) . '<span class="screen-reader-text">' . esc_html__( 'Tags', 'the-business-wp' ) . '</span>' .$tags_list. '</span>';
					}

					echo '</span>';
				}
			}

			the_business_wp_edit_link();

			echo '</footer> <!-- .entry-footer -->';
		}
	}
endif;

/**
 * @Package twentyseventeen
 * @subpackage the-business-wp
 * @since the-business-wp 1.0
 */
if ( ! function_exists( 'the_business_wp_edit_link' ) ) :
	/**
	 * Returns an accessibility-friendly link to edit a post or page.
	 * Helpful when/if the single-page
	 * layout with multiple posts/pages shown gets confusing.
	 */
	function the_business_wp_edit_link() {
		edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			esc_html__( 'Edit %s', 'the-business-wp' ),
			the_title( '<span class="screen-reader-text">"', '"</span>', false )
		),
		'<span class="edit-link">',
		'</span>'
		);
	}
endif;


if ( ! function_exists( 'the_business_wp_woo_products' ) ){
/**
 * Displays list of woocommerce products in front page
 *
 */
function the_business_wp_woo_products( $products_show, $show_featured=false ) {
	
	if(!class_exists( 'WooCommerce' )){return;}
	//woocommerce products are custom posts named product
	$args = array(
		'post_type' => 'product',
	);
	
	if (empty( $products_show )){ 
	    $args['posts_per_page']= $products_show ;
	}
	else{ 
	    $args['posts_per_page']= 4 ;
	}	
	
	
	//if show featured pages
	if($show_featured){
	$args = array(
		'post_type' => 'product',
		'posts_per_page' => $args['posts_per_page'],
		'tax_query' => array(
				array(
					'taxonomy' => 'product_visibility',
					'field'    => 'name',
					'terms'    => 'featured',
				),
			),
		);
	}
	
	$loop = new WP_Query( $args );
	if ( $loop->have_posts() ) :
	$i = 1;
	
		while ( $loop->have_posts() ) :
			$loop->the_post();
			global $product;
			global $post;
			?>
			<div class="col-md-3 col-sm-3 col-xs-12 ">
				<div class="featured-woo">
					<?php if ( has_post_thumbnail() ) : ?>
					<div class="image-area">
						<a href="<?php echo esc_url( get_permalink() ); ?>" title="<?php the_title_attribute(); ?>">
						<?php the_post_thumbnail('full', array( 'alt' => esc_html(get_the_title()) )); ?>
						</a>
					</div>
					<?php endif; ?>		
							
					<div class="woo-featured">
					<?php
					$categories = "";
						if ( function_exists( 'wc_get_product_category_list' ) ) {
								$prod_id = get_the_ID();
								$categories = wc_get_product_category_list( $prod_id );
							} else {
								$categories = $product->get_categories();
							}
					 ?>					
					<span>
					<?php
						$args = array(
							//links
								'a'    => array(
								'href' => array(),
								'target' => array(),
								'rel' => array(),
							)
						);						
						echo wp_kses($categories,$args); 
					?></span>					
					<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">
						<h4><?php esc_html( the_title() ); ?></h4>
					</a>
					
					<?php if ( $post->post_excerpt ) : ?>
					<div class="woo-product-description">
						<?php echo wp_kses((apply_filters( 'woocommerce_short_description', $post->post_excerpt )), array('p'=> array())); ?>
					</div>
					<?php endif; ?>
							<?php
							
							$price = $product->get_price_html();
							
							if ( ! empty( $price ) ) {

								echo '<h4>';

								echo wp_kses(
									$price, array(
										'span' => array(
											'class' => array(),
										),
										'del' => array(),
									)
								);

								echo '</h4>';

							}
							?>
					
										
					<div class="start-add-to-cart woocommerce button">
						<?php the_business_wp_add_to_cart(); ?>
					</div>										
				</div>
			  </div>				
			</div>
			<?php
			if ( $i % 4 == 0 ) {
				echo '<div class="clearfix"></div>';				
			}
				$i++;
				
		endwhile;
		wp_reset_postdata();
	endif;
 } 
 
}


if ( ! function_exists( 'the_business_wp_free_checkout_fields' ) ) :
/**
 * Removes coupon form, order notes, and several billing fields if the checkout doesn't require payment.
 */
function the_business_wp_free_checkout_fields() {
 	if (!class_exists( 'WooCommerce' ) ) {return;}
	// first, bail if the cart needs payment, we don't want to do anything
	if ( WC()->cart && WC()->cart->needs_payment() ) {
		return;	
	}
	// now continue only if we're at checkout
	// is_checkout() was broken as of WC 3.2 in ajax context, double-check for is_ajax
	if ( function_exists( 'is_checkout' ) && ( is_checkout() || is_ajax() ) ) {
		// remove coupon forms since why would you want a coupon for a free cart??
		remove_action( 'woocommerce_before_checkout_form', 'woocommerce_checkout_coupon_form', 10 );
		// Remove the "Additional Info" order notes
		add_filter( 'woocommerce_enable_order_notes_field', '__return_false' );
		// Unset the fields we don't want in a free checkout
		function the_business_wp_unset_unwanted_checkout_fields( $fields ) {
			// add or remove billing fields you do not want
			// fields: http://docs.woothemes.com/document/tutorial-customising-checkout-fields-using-actions-and-filters/#section-2
			$billing_keys = array(
				'billing_first_name',
				'billing_last_name',
				'billing_email',
				'billing_company',
				'billing_company',
				'billing_phone',
				'billing_address_1',
				'billing_address_2',
				'billing_city',
				'billing_postcode',
				'billing_country',
				'billing_state',
			);
			// unset each of those unwanted fields
			foreach( $billing_keys as $key ) {
				unset( $fields['billing'][ $key ] );
			}
			return $fields;
		}
		add_filter( 'woocommerce_checkout_fields', 'the_business_wp_unset_unwanted_checkout_fields' );
	}
}
endif;

//remove some free checkout feelds for free products
global $the_business_wp_option;
if(class_exists( 'WooCommerce' ) && $the_business_wp_option['woocommerce_free_checkout_feelds']){
	add_action( 'wp', 'the_business_wp_free_checkout_fields' );
}

/**
 * Woocommerce Custom add to cart button
 *
 */
if ( ! function_exists( 'the_business_wp_add_to_cart' ) ) {
	function the_business_wp_add_to_cart() {
		
		if(!class_exists( 'WooCommerce' )){return;}
		global $product;

		if ( function_exists( 'method_exists' ) && method_exists( $product, 'get_type' ) ) {
			$prod_type = $product->get_type();
		} else {
			$prod_type = $product->product_type;
		}

		if ( function_exists( 'method_exists' ) && method_exists( $product, 'get_stock_status' ) ) {
			$prod_in_stock = $product->get_stock_status();
		} else {
			$prod_in_stock = $product->is_in_stock();
		}

		if ( $product ) {
			$args = array();
			$defaults = array(
				'quantity' => 1,
				'class'    => implode(
					' ', array_filter(
						array(
							'button',
							'product_type_' . $prod_type,
							$product->is_purchasable() && $prod_in_stock ? 'add_to_cart_button' : '',
							$product->supports( 'ajax_add_to_cart' ) ? 'ajax_add_to_cart' : '',
						)
					)
				),
			);

			$args = apply_filters( 'woocommerce_loop_add_to_cart_args', wp_parse_args( $args, $defaults ), $product );

			wc_get_template( 'woocommerce/add-to-cart.php', $args );
		}
	}
}

if ( ! function_exists( 'the_business_wp_wc_custom_get_price_html' ) ) :
/* when price empty return 0$ */
function the_business_wp_wc_custom_get_price_html( $price, $product ) {
	if(!class_exists( 'WooCommerce' )){return;}
	if ( $product->get_price() == 0 ) {
		if ( $product->is_on_sale() && $product->get_regular_price() ) {
			$regular_price = wc_get_price_to_display( $product, array( 'qty' => 1, 'price' => $product->get_regular_price() ) );
			$price = wc_format_price_range( $regular_price, __( 'Free!', 'the-business-wp' ) );
		} else {
			$price = '<span class="amount">' . __( 'Free!', 'the-business-wp' ) . '</span>';
		}
	}

	return $price;
}
endif;

add_filter( 'woocommerce_get_price_html', 'the_business_wp_wc_custom_get_price_html', 10, 2 );

/**
 * Add Cart icon and count to header if WC is active
 */
function the_business_wp_wc_cart_count() {
 
    if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
 
        //$count = WC()->cart->cart_contents_count;
		$count = WC()->cart->get_cart_total();
        ?><a class="cart-contents" href="<?php echo esc_url(wc_get_cart_url()); ?>" title="<?php esc_attr_e('View your shopping cart','the-business-wp' ); ?>">
            <span class="cart-contents-count"><?php echo absint($count); ?></span>
           </a>
		<?php
    } else {
	?>
	<span class="cart-contents-count">0</span>
    </a>	
	<?php
	}
 
}
add_action( 'the_business_wp_woocommerce_cart_top', 'the_business_wp_wc_cart_count' );

if ( ! function_exists( 'the_business_wp_add_to_cart_fragment' ) ) :
/**
 * Ensure cart contents update when products are added to the cart via AJAX
 */
function the_business_wp_add_to_cart_fragment( $fragments ) {
 
    ob_start();
    $count = WC()->cart->cart_contents_count;
    ?><a class="cart-contents" href="<?php echo esc_url(wc_get_cart_url()); ?>" title="<?php esc_attr_e( 'View your shopping cart','the-business-wp' ); ?>">
	<span class="cart-contents-count"><?php echo absint($count); ?></span>
    </a><?php
 
    $fragments['a.cart-contents'] = ob_get_clean(); 
     
    return $fragments;
}
endif;

add_filter( 'woocommerce_add_to_cart_fragments', 'the_business_wp_add_to_cart_fragment' );

/**
 *Returns true if a blog has more than 1 category.
 * @Package twentyseventeen
 * @subpackage the-business-wp
 * @since the-business-wp 1.0
 */
function the_business_wp_categorized_blog() {
	$category_count = get_transient( 'the_business_wp_categories' );

	if ( false === $category_count ) {
		// Create an array of all the categories that are attached to posts.
		$categories = get_categories(
			array(
				'fields'     => 'ids',
				'hide_empty' => 1,
				// We only need to know if there is more than one category.
				'number'     => 2,
			)
		);

		// Count the number of categories that are attached to the posts.
		$category_count = count( $categories );

		set_transient( 'the_business_wp_categories', $category_count );
	}

	// Allow viewing case of 0 or 1 categories in post preview.
	if ( is_preview() ) {
		return true;
	}

	return $category_count > 1;
}



/**
 * Flush out the transients used in the_business_wp_categorized_blog.
 * @Package twentyseventeen
 * @subpackage the-business-wp
 * @since the-business-wp 1.0
 */

function the_business_wp_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'the_business_wp_categories' );
}
add_action( 'edit_category', 'the_business_wp_category_transient_flusher' );
add_action( 'save_post', 'the_business_wp_category_transient_flusher' );

if ( ! function_exists( 'the_business_wp_font_family' ) ) :
function the_business_wp_font_family(){

	$google_fonts = array("Open Sans" => "Open Sans",
						  "Oswald" => "Oswald",
						  "PT Sans" => "PT Sans",
						  "Times New Roman, Sans Serif" => "Times New Roman, Sans Serif");
	return $google_fonts;

}
endif;

function the_business_wp_footer_foreground_css(){

	$color =  esc_attr(get_theme_mod( 'footer_foreground_color','#fff')) ;
	$theme_color = '#2d89ef';
	
	if ( 'default' == get_theme_mod( 'colorscheme','default' )) {
    	$theme_color = esc_attr(get_theme_mod( 'colorscheme_color','#2d89ef')) ;
	}
	
	/**
	 *
	 * @since business-wp 1.0
	 *
	 */

$css                = '

.footer-foreground {}
.footer-foreground .widget-title, 
.footer-foreground a, 
.footer-foreground p, 
.footer-foreground li,
.footer-foreground table,
.footer-foreground .widget
{
  color:'.$color.';
}

.footer-foreground a:hover, .footer-foreground a:active {color:'.$theme_color.';}

';

return $css;

}